summaryrefslogtreecommitdiff
path: root/DuetPkg/FSVariable/FSVariable.c
diff options
context:
space:
mode:
Diffstat (limited to 'DuetPkg/FSVariable/FSVariable.c')
-rw-r--r--DuetPkg/FSVariable/FSVariable.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/DuetPkg/FSVariable/FSVariable.c b/DuetPkg/FSVariable/FSVariable.c
index 49e92076e1..c41467c6f8 100644
--- a/DuetPkg/FSVariable/FSVariable.c
+++ b/DuetPkg/FSVariable/FSVariable.c
@@ -553,9 +553,9 @@ Returns:
Get index from supported language codes according to language string.
This code is used to get corresponding index in supported language codes. It can handle
- RFC3066 and ISO639 language tags.
+ RFC4646 and ISO639 language tags.
In ISO639 language tags, take 3-characters as a delimitation to find matched string and calculate the index.
- In RFC3066 language tags, take semicolon as a delimitation to find matched string and calculate the index.
+ In RFC4646 language tags, take semicolon as a delimitation to find matched string and calculate the index.
For example:
SupportedLang = "engfraengfra"
@@ -570,7 +570,7 @@ Returns:
@param SupportedLang Platform supported language codes.
@param Lang Configured language.
- @param Iso639Language A bool value to signify if the handler is operated on ISO639 or RFC3066.
+ @param Iso639Language A bool value to signify if the handler is operated on ISO639 or RFC4646.
@retval the index of language in the language codes.
@@ -604,7 +604,7 @@ GetIndexFromSupportedLangCodes(
return 0;
} else {
//
// Compare RFC3066 language code
//
while (*Supported != '\0') {
//
@@ -630,9 +630,9 @@ GetIndexFromSupportedLangCodes(
Get language string from supported language codes according to index.
This code is used to get corresponding language string in supported language codes. It can handle
- RFC3066 and ISO639 language tags.
+ RFC4646 and ISO639 language tags.
In ISO639 language tags, take 3-characters as a delimitation. Find language string according to the index.
- In RFC3066 language tags, take semicolon as a delimitation. Find language string according to the index.
+ In RFC4646 language tags, take semicolon as a delimitation. Find language string according to the index.
For example:
SupportedLang = "engfraengfra"
@@ -647,7 +647,7 @@ GetIndexFromSupportedLangCodes(
@param SupportedLang Platform supported language codes.
@param Index the index in supported language codes.
- @param Iso639Language A bool value to signify if the handler is operated on ISO639 or RFC3066.
+ @param Iso639Language A bool value to signify if the handler is operated on ISO639 or RFC4646.
@retval the language string in the language codes.
@@ -769,7 +769,7 @@ AutoUpdateLangVariable(
Index = GetIndexFromSupportedLangCodes(mGlobal->PlatformLangCodes, BestPlatformLang, FALSE);
//
// Get the corresponding ISO639 language tag according to RFC3066 language tag.
//
BestLang = GetLangFromSupportedLangCodes(mGlobal->LangCodes, Index, TRUE);
@@ -799,7 +799,7 @@ AutoUpdateLangVariable(
Index = GetIndexFromSupportedLangCodes(mGlobal->LangCodes, BestLang, TRUE);
//
// Get the corresponding RFC3066 language tag according to ISO639 language tag.
//
BestPlatformLang = GetLangFromSupportedLangCodes(mGlobal->PlatformLangCodes, Index, FALSE);
@@ -604,7 +604,7 @@ GetIndexFromSupportedLangCodes(
} else {
//
- // Compare RFC3066 language code
+ // Compare RFC4646 language code
//
while (*Supported != '\0') {
@@ -769,7 +769,7 @@ AutoUpdateLangVariable(
Index = GetIndexFromSupportedLangCodes(mGlobal->PlatformLangCodes, BestPlatformLang, FALSE);
//
- // Get the corresponding ISO639 language tag according to RFC3066 language tag.
+ // Get the corresponding ISO639 language tag according to RFC4646 language tag.
//
BestLang = GetLangFromSupportedLangCodes(mGlobal->LangCodes, Index, TRUE);
@@ -799,7 +799,7 @@ AutoUpdateLangVariable(
Index = GetIndexFromSupportedLangCodes(mGlobal->LangCodes, BestLang, TRUE);
//
- // Get the corresponding RFC3066 language tag according to ISO639 language tag.
+ // Get the corresponding RFC4646 language tag according to ISO639 language tag.
//
BestPlatformLang = GetLangFromSupportedLangCodes(mGlobal->PlatformLangCodes, Index, FALSE);